"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAnimationFrame = void 0;
const react_1 = require("react");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useAnimationFrame | useAnimationFrame} hook.
 */
const useAnimationFrame = (args) => {
    const frameRequestId = (0, react_1.useRef)();
    const [isStarted, setIsStarted] = (0, react_1.useState)(!!args.startOnMount);
    const handleAnimationFrameRequest = (0, react_1.useCallback)(timestamp => {
        args.callback(timestamp);
        frameRequestId.current = window.requestAnimationFrame(handleAnimationFrameRequest);
    }, [args.callback]);
    const startAnimationFrame = (0, react_1.useCallback)(() => {
        setIsStarted(true);
        if (frameRequestId.current === undefined)
            frameRequestId.current = window.requestAnimationFrame(handleAnimationFrameRequest);
    }, []);
    const stopAnimationFrame = (0, react_1.useCallback)(() => {
        setIsStarted(false);
        if (frameRequestId.current !== undefined)
            window.cancelAnimationFrame(frameRequestId.current);
        frameRequestId.current = undefined;
    }, []);
    const toggle = (0, react_1.useCallback)((start) => {
        const shouldStart = start ?? !isStarted;
        shouldStart ? startAnimationFrame() : stopAnimationFrame();
    }, [isStarted]);
    (0, react_1.useEffect)(() => {
        if (args.startOnMount)
            startAnimationFrame();
    }, []);
    return { start: startAnimationFrame, cancel: stopAnimationFrame, toggle, isStarted };
};
exports.useAnimationFrame = useAnimationFrame;
//# sourceMappingURL=index.js.map