"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useArray = void 0;
const react_1 = require("react");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useArray | useArray} hook.
 */
const useArray = (initial = []) => {
    const [array, setArray] = (0, react_1.useState)(initial);
    return (0, react_1.useMemo)(() => ({
        array,
        length: array.length,
        get(index) {
            return array.at(index);
        },
        set(index, element) {
            setArray(arr => arr.toSpliced(index, 1, element));
        },
        has(...elements) {
            return elements.every(value => array.includes(value));
        },
        count(element) {
            return array.reduce((acc, value) => (value === element ? acc + 1 : acc), 0);
        },
        push(...elements) {
            setArray(arr => arr.toSpliced(arr.length, 0, ...elements));
        },
        pop(index = -1) {
            setArray(arr => arr.toSpliced(index, 1));
            return array.at(index);
        },
        shift() {
            return this.pop(0);
        },
        unshift(...elements) {
            this.insert(0, ...elements);
        },
        insert(index, ...elements) {
            setArray(arr => arr.toSpliced(index, 0, ...elements));
        },
        reset(value = initial) {
            setArray(value);
        }
    }), [array]);
};
exports.useArray = useArray;
//# sourceMappingURL=index.js.map