"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAsyncCallback = void 0;
const react_1 = require("react");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useAsyncCallback | useAsyncCallback} hook.
 */
const useAsyncCallback = (callback) => {
    const [isPending, setIsPending] = (0, react_1.useState)(false);
    const [error, setError] = (0, react_1.useState)();
    const [data, setData] = (0, react_1.useState)();
    const callbackMemo = (0, react_1.useCallback)(async () => {
        if (isPending)
            return;
        setIsPending(true);
        setError(undefined);
        try {
            setData(await callback());
        }
        catch (error) {
            setError(error);
        }
        finally {
            setIsPending(false);
        }
    }, [callback, isPending]);
    const clear = (0, react_1.useCallback)(() => {
        setData(undefined);
        setIsPending(false);
        setError(undefined);
    }, []);
    return { data, isPending, error, callback: callbackMemo, clear };
};
exports.useAsyncCallback = useAsyncCallback;
//# sourceMappingURL=index.js.map