"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAudioAnalyser = void 0;
const react_1 = require("react");
const useAnimationFrame_1 = require("../useAnimationFrame");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useAudioAnalyser | useAudioAnalyser} hook.
 */
const useAudioAnalyser = (args) => {
    const context = (0, react_1.useRef)();
    const analyserNode = (0, react_1.useRef)();
    const dataArray = (0, react_1.useRef)(new Uint8Array());
    const frame = (0, useAnimationFrame_1.useAnimationFrame)({
        callback: () => {
            analyserNode.current?.getByteFrequencyData(dataArray.current);
            args.handler(dataArray.current);
        }
    });
    const connect = (0, react_1.useCallback)(async (source) => {
        if (!context.current || !analyserNode.current)
            return;
        const isStream = source instanceof MediaStream;
        // avoid the CORS access restrictions
        if (!isStream)
            source.crossOrigin = 'anonymous';
        try {
            const sourceNode = isStream
                ? context.current.createMediaStreamSource(source)
                : context.current.createMediaElementSource(source);
            sourceNode.connect(analyserNode.current);
            if (!isStream)
                sourceNode.connect(context.current.destination);
            // fix the AudioContext suspending in Chrome
            if (context.current.state === 'suspended')
                await context.current?.resume();
            frame.start();
            return sourceNode;
        }
        catch (error) {
            if (error.message.includes('already connected'))
                return;
            throw error;
        }
    }, []);
    const disconnect = (0, react_1.useCallback)(() => {
        analyserNode.current?.disconnect();
        frame.cancel();
    }, []);
    (0, react_1.useEffect)(() => {
        // @ts-ignore
        context.current = new (window.AudioContext || window.webkitAudioContext)();
        analyserNode.current = context.current.createAnalyser();
        analyserNode.current.fftSize = args.fftSize ?? 2048;
        dataArray.current = new Uint8Array(analyserNode.current.frequencyBinCount);
        return disconnect;
    }, []);
    return { nodeRef: analyserNode, context, connect, disconnect };
};
exports.useAudioAnalyser = useAudioAnalyser;
//# sourceMappingURL=index.js.map