"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useClipboard = void 0;
const react_1 = require("react");
const useTimeout_1 = require("../useTimeout");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useClipboard | useClipboard} hook.
 */
const useClipboard = (args = {}) => {
    const statusTimer = (0, useTimeout_1.useTimeout)({ timeout: args.duration ?? 2500 });
    const controls = (0, react_1.useMemo)(() => ({
        isCopied: statusTimer.isActive,
        copy: async (data) => {
            if (!data)
                return;
            typeof data == 'string'
                ? await navigator.clipboard.writeText(data)
                : await navigator.clipboard.write(Array.isArray(data) ? data : [data]);
            statusTimer.start();
        },
        paste: async () => {
            return await navigator.clipboard.readText();
        },
        pasteData: async (type) => {
            const data = await navigator.clipboard.read();
            return data.filter(item => item.types.some(t => t.startsWith(type)));
        },
        reset: () => {
            statusTimer.cancel();
        }
    }), [statusTimer]);
    return controls;
};
exports.useClipboard = useClipboard;
//# sourceMappingURL=index.js.map