"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCounter = void 0;
const react_1 = require("react");
const utils_1 = require("../utils");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useCounter | useCounter} hook.
 */
const useCounter = (args = {}) => {
    const initialValue = Math.floor(args.initial ?? 0);
    const [counter, setCounter] = (0, react_1.useState)(initialValue);
    const counterMin = Math.min(counter, args.min ?? -Infinity);
    const counterMax = Math.max(counter, args.max ?? Infinity);
    const methods = (0, react_1.useMemo)(() => ({
        value: counter,
        inc(step = 1) {
            this.set(v => v + (0, utils_1.getStateActionValue)(step, v));
        },
        dec(step = 1) {
            this.set(v => v - (0, utils_1.getStateActionValue)(step, v));
        },
        set(value) {
            setCounter(v => {
                const resolvedValue = (0, utils_1.getStateActionValue)(value, v);
                return resolvedValue > counterMax
                    ? counterMax
                    : resolvedValue < counterMin
                        ? counterMin
                        : resolvedValue;
            });
        },
        reset() {
            this.set(initialValue);
        }
    }), [counter]);
    return methods;
};
exports.useCounter = useCounter;
//# sourceMappingURL=index.js.map