"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDragAndDrop = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const utils_1 = require("../utils");
const useNewRef_1 = require("../utils/useNewRef");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useDragAndDrop | useDragAndDrop} hook.
 */
const useDragAndDrop = (args) => {
    const targetRef = (0, useNewRef_1.useNewRef)(args.ref);
    const draggedElement = (0, react_1.useRef)();
    const initialPosition = (0, react_1.useRef)();
    const callback = (0, react_1.useCallback)((type, event) => {
        if (!draggedElement.current || !initialPosition.current)
            return;
        const currentPosition = (0, utils_1.getPointerPosition)(event);
        args.handler({
            type,
            clientX: currentPosition.x,
            clientY: currentPosition.y,
            initialX: initialPosition.current.x,
            initialY: initialPosition.current.y,
            target: draggedElement.current,
            event
        });
    }, [args.handler]);
    const handleMouseDown = (0, react_1.useCallback)((event) => {
        if (!event.target || event.target === targetRef.current)
            return;
        draggedElement.current = event.target;
        initialPosition.current = (0, utils_1.getPointerPosition)(event);
        callback('start', event);
    }, [callback]);
    const handleDragging = (0, react_1.useCallback)((event) => callback('moving', event), [callback]);
    const handleDropping = (0, react_1.useCallback)((event) => {
        callback('end', event);
        draggedElement.current = undefined;
        initialPosition.current = undefined;
    }, [callback]);
    (0, useEventListener_1.useEventListener)({ event: 'pointermove', handler: handleDragging, ref: targetRef });
    (0, useEventListener_1.useEventListener)({ event: 'pointerdown', handler: handleMouseDown, ref: targetRef });
    (0, useEventListener_1.useEventListener)({
        event: ['pointerup', 'pointerleave', 'pointercancel'],
        handler: handleDropping,
        ref: targetRef
    });
    return targetRef;
};
exports.useDragAndDrop = useDragAndDrop;
//# sourceMappingURL=index.js.map