"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFileDropArea = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useNewRef_1 = require("../utils/useNewRef");
const getFileInputElement = (label) => {
    if ('htmlFor' in label && label.htmlFor)
        return document.getElementById(label.htmlFor);
    return label.querySelector('input[type="file"]');
};
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useFileDropArea | useFileDropArea} hook.
 */
const useFileDropArea = (args = {}) => {
    const targetRef = (0, useNewRef_1.useNewRef)(args.ref);
    const getDropperFiles = (0, react_1.useCallback)(async (inputFiles) => {
        if (!inputFiles)
            return;
        const files = Array.from(inputFiles);
        if (!files.length)
            return;
        const resolvedFiles = args.multiple ? files : [files[0]];
        await args.handler?.(resolvedFiles);
    }, [args.handler]);
    (0, react_1.useEffect)(() => {
        if (!targetRef.current)
            return;
        const fileInput = getFileInputElement(targetRef.current);
        if (!fileInput)
            return;
        const handleInputChange = async () => {
            await getDropperFiles(fileInput?.files);
            // add a value property to use the file input multiple times
            fileInput.value = '';
        };
        fileInput.multiple = !!args.multiple;
        fileInput.addEventListener('change', handleInputChange);
        return () => fileInput?.removeEventListener('change', handleInputChange);
    }, [getDropperFiles]);
    const handleFileDrop = (0, react_1.useCallback)(async (event) => {
        event.preventDefault();
        getDropperFiles(event.dataTransfer?.files);
    }, []);
    const handleFilePaste = (0, react_1.useCallback)((event) => {
        event.preventDefault();
        getDropperFiles(event.clipboardData?.files);
    }, []);
    (0, useEventListener_1.useEventListener)({ event: 'drop', handler: handleFileDrop, ref: targetRef });
    (0, useEventListener_1.useEventListener)({ event: 'paste', handler: handleFilePaste, ref: targetRef });
    (0, useEventListener_1.useEventListener)({ event: 'dragover', handler: e => e.preventDefault(), ref: targetRef });
    return targetRef;
};
exports.useFileDropArea = useFileDropArea;
//# sourceMappingURL=index.js.map