"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFullscreen = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const utils_1 = require("../utils");
const useNewRef_1 = require("../utils/useNewRef");
const fullscreenChangeEvents = utils_1.browserPrefixes.map(pref => pref + 'fullscreenchange');
const fullscreenErrorEvents = utils_1.browserPrefixes.map(pref => pref + 'fullscreenerror');
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useFullscreen | useFullscreen} hook.
 */
const useFullscreen = (ref) => {
    const targetRef = (0, useNewRef_1.useNewRef)(ref);
    const [isEnabled, setIsEnabled] = (0, react_1.useState)(false);
    const [isError, setIsError] = (0, react_1.useState)(false);
    const getTarget = (0, react_1.useCallback)(() => targetRef.current ?? document.body, [targetRef]);
    const controls = (0, react_1.useMemo)(() => ({
        ref: targetRef,
        isEnabled,
        isError,
        async enter(options = {}) {
            const requestFullscreen = (0, utils_1.getPrefixedProperty)(getTarget(), 'requestFullscreen');
            if (!requestFullscreen)
                return;
            setIsError(false);
            await requestFullscreen(options);
            setIsEnabled(true);
        },
        async exit() {
            const exitFullscreen = (0, utils_1.getPrefixedProperty)(document, 'exitFullscreen');
            if (!exitFullscreen)
                return;
            setIsError(false);
            await exitFullscreen();
            setIsEnabled(false);
        },
        async toggle(enable) {
            const shouldEnable = enable ?? !isEnabled;
            shouldEnable ? await this.enter() : await this.exit();
        }
    }), [isEnabled]);
    const handleFullScreenChange = (0, react_1.useCallback)(() => {
        const fullscreenElement = (0, utils_1.getPrefixedProperty)(document, 'fullscreenElement');
        setIsEnabled(fullscreenElement === getTarget());
    }, []);
    const handleFullScreenError = (0, react_1.useCallback)(() => {
        setIsError(true);
    }, []);
    (0, useEventListener_1.useEventListener)({
        event: fullscreenChangeEvents,
        handler: handleFullScreenChange,
        target: () => {
            handleFullScreenChange();
            return document;
        }
    });
    (0, useEventListener_1.useEventListener)({
        event: fullscreenErrorEvents,
        handler: handleFullScreenError,
        target: () => document
    });
    return controls;
};
exports.useFullscreen = useFullscreen;
//# sourceMappingURL=index.js.map