"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGamepad = void 0;
const react_1 = require("react");
const useAnimationFrame_1 = require("../useAnimationFrame");
const useEventListener_1 = require("../useEventListener");
const getGamepadState = (gamepad) => {
    return {
        isConnected: gamepad.connected,
        A: gamepad.buttons[0],
        B: gamepad.buttons[1],
        X: gamepad.buttons[2],
        Y: gamepad.buttons[3],
        LB: gamepad.buttons[4],
        RB: gamepad.buttons[5],
        LT: gamepad.buttons[6],
        RT: gamepad.buttons[7],
        SELECT: gamepad.buttons[8],
        START: gamepad.buttons[9],
        UP: gamepad.buttons[12],
        DOWN: gamepad.buttons[13],
        LEFT: gamepad.buttons[14],
        RIGHT: gamepad.buttons[15],
        leftStick: { button: gamepad.buttons[10], x: gamepad.axes[0], y: gamepad.axes[1] },
        rightStick: { button: gamepad.buttons[11], x: gamepad.axes[2], y: gamepad.axes[3] }
    };
};
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useGamepad | useGamepad} hook.
 */
const useGamepad = (args) => {
    const index = args.index ?? 0;
    const [isConnected, setIsConnected] = (0, react_1.useState)(false);
    const handleGamepadState = (0, react_1.useCallback)(() => {
        const gamepad = navigator.getGamepads()[index];
        if (!gamepad)
            return;
        args.handler(getGamepadState(gamepad));
    }, [index, args.handler]);
    const frame = (0, useAnimationFrame_1.useAnimationFrame)({ callback: handleGamepadState, startOnMount: false });
    const handleGamepadConnection = (0, react_1.useCallback)(() => {
        if (!navigator.getGamepads)
            return;
        const gamepad = navigator.getGamepads()[index];
        setIsConnected(!!gamepad?.connected);
        gamepad ? frame.start() : frame.cancel();
    }, [index, frame]);
    (0, react_1.useEffect)(() => {
        handleGamepadConnection();
    }, [index]);
    (0, useEventListener_1.useEventListener)({
        event: ['gamepadconnected', 'gamepaddisconnected'],
        handler: handleGamepadConnection,
        target: () => window
    });
    return isConnected;
};
exports.useGamepad = useGamepad;
//# sourceMappingURL=index.js.map