"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useInterval = void 0;
const react_1 = require("react");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useInterval | useInterval} hook.
 */
const useInterval = (args) => {
    const intervalRef = (0, react_1.useRef)();
    const [isActive, setIsActive] = (0, react_1.useState)(!!args.startOnMount);
    const controls = (0, react_1.useMemo)(() => ({
        isActive,
        start() {
            this.stop();
            intervalRef.current = setInterval(args.callback, args.timeout);
            setIsActive(true);
        },
        stop() {
            if (!intervalRef.current)
                return;
            setIsActive(false);
            window.clearInterval(intervalRef.current);
        },
        toggle(force) {
            const shouldStart = force ?? !isActive;
            shouldStart ? this.start() : this.stop();
        }
    }), [args.callback, isActive]);
    (0, react_1.useEffect)(() => {
        if (!args.startOnMount)
            return;
        controls.start();
        return controls.stop;
    }, args.deps ?? []);
    return controls;
};
exports.useInterval = useInterval;
//# sourceMappingURL=index.js.map