"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useKeyboard = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useNewRef_1 = require("../utils/useNewRef");
const getKeyboardEventList = (record = {}, sep = '|') => {
    return Object.keys(record).map(key => {
        const resolvedKeys = key.split(sep).map(k => k.trim().toLowerCase());
        return [resolvedKeys, record[key]];
    });
};
const isPressed = (keyModifier, event) => {
    return keyModifier.split('+').every(key => {
        switch (key.trim()) {
            case 'ctrl':
                return event.ctrlKey;
            case 'alt':
                return event.altKey;
            case 'shift':
                return event.shiftKey;
            case 'meta':
                return event.metaKey;
            default:
                return event.key.toLowerCase() === key || event.code.toLowerCase() === key;
        }
    });
};
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useKeyboard | useKeyboard} hook.
 */
const useKeyboard = (args) => {
    const targetRef = (0, useNewRef_1.useNewRef)(args.ref);
    const keyboardEventList = (0, react_1.useMemo)(() => getKeyboardEventList(args.keys, args.separator), [args.keys]);
    const handleKeydown = (0, react_1.useCallback)((event) => {
        const pressedKeyEvent = keyboardEventList.find(([keys, _]) => {
            return keys.some(key => isPressed(key, event));
        });
        if (pressedKeyEvent)
            pressedKeyEvent[1](event);
    }, [keyboardEventList]);
    (0, useEventListener_1.useEventListener)({
        event: 'keydown',
        handler: handleKeydown,
        target: () => targetRef.current ?? window
    });
    return targetRef;
};
exports.useKeyboard = useKeyboard;
//# sourceMappingURL=index.js.map