"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMediaDevices = void 0;
const react_1 = require("react");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useMediaDevices | useMediaDevices} hook.
 */
const useMediaDevices = (args = {}) => {
    const [stream, setStream] = (0, react_1.useState)(null);
    const [devices, setDevices] = (0, react_1.useState)([]);
    const stopStreaming = (0, react_1.useCallback)(() => {
        setStream(prev => {
            prev?.getTracks().forEach(t => t.stop());
            return null;
        });
    }, []);
    const startStreaming = (0, react_1.useCallback)(async (constraints) => {
        const currentTracks = stream?.getTracks();
        // stop the current stream tracks so that the next tracks will start
        currentTracks?.forEach(t => t.stop());
        const newStream = await navigator.mediaDevices.getUserMedia(constraints ?? args);
        // disable the tracks that were enabled in the previous stream
        if (currentTracks) {
            for (const track of newStream.getTracks()) {
                const current = currentTracks.find(t => t.kind === track.kind);
                if (current)
                    track.enabled = current.enabled;
            }
        }
        setStream(newStream);
        return newStream;
    }, [stream]);
    const updateMediaDevices = (0, react_1.useCallback)(async () => {
        setDevices(await navigator.mediaDevices.enumerateDevices());
    }, []);
    (0, react_1.useEffect)(() => {
        if (args.startOnMount)
            startStreaming();
        updateMediaDevices();
        navigator.mediaDevices.addEventListener('devicechange', updateMediaDevices);
        return () => navigator.mediaDevices.removeEventListener('devicechange', updateMediaDevices);
    }, []);
    return { stream, devices, start: startStreaming, stop: stopStreaming };
};
exports.useMediaDevices = useMediaDevices;
//# sourceMappingURL=index.js.map