"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useNetworkState = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useIsomorphicEffect_1 = require("../useIsomorphicEffect");
const utils_1 = require("../utils");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useNetworkState | useNetworkState} hook.
 */
const useNetworkState = () => {
    const connection = (0, react_1.useRef)();
    const [isOnline, setIsOnline] = (0, react_1.useState)(true);
    const [networkInfo, setNetworkInfo] = (0, react_1.useState)({});
    const getConnectionState = (0, react_1.useCallback)(() => {
        if (!connection.current)
            return {};
        return {
            type: connection.current?.type,
            rtt: connection.current?.rtt,
            downlink: connection.current?.downlink,
            downlinkMax: connection.current?.downlinkMax,
            effectiveType: connection.current?.effectiveType,
            saveData: connection.current?.saveData
        };
    }, []);
    const updateConnection = (0, react_1.useCallback)(async () => {
        setNetworkInfo(getConnectionState);
        try {
            const response = await fetch('https://httpbin.org/status/200');
            if (response.ok)
                setIsOnline(true);
        }
        catch (error) {
            setIsOnline(false);
        }
    }, []);
    (0, useIsomorphicEffect_1.useIsomorphicEffect)(() => {
        connection.current = (0, utils_1.getPrefixedProperty)(navigator, 'connection');
        updateConnection();
    }, []);
    (0, useEventListener_1.useEventListener)({
        event: ['change', 'typechange'],
        handler: updateConnection,
        ref: connection
    });
    (0, useEventListener_1.useEventListener)({
        event: ['online', 'offline'],
        handler: () => setIsOnline(navigator.onLine),
        target: () => window
    });
    return { ...networkInfo, isOnline };
};
exports.useNetworkState = useNetworkState;
//# sourceMappingURL=index.js.map