"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePageVisibility = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const utils_1 = require("../utils");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/usePageVisibility | usePageVisibility} hook.
 */
const usePageVisibility = () => {
    const [isVisible, setIsVisible] = (0, react_1.useState)(true);
    const handleVisibilityChange = (0, react_1.useCallback)((force) => {
        if (force !== undefined)
            return setIsVisible(force);
        setIsVisible(!(0, utils_1.getPrefixedProperty)(document, 'hidden'));
    }, []);
    (0, useEventListener_1.useEventListener)({
        event: ['focus', 'blur'],
        handler: e => handleVisibilityChange(e.type === 'focus'),
        target: () => window
    });
    (0, useEventListener_1.useEventListener)({
        event: 'visibilitychange',
        handler: () => handleVisibilityChange(),
        target: () => document
    });
    return isVisible;
};
exports.usePageVisibility = usePageVisibility;
//# sourceMappingURL=index.js.map