"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePointers = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useNewRef_1 = require("../utils/useNewRef");
const pointerEvents = [
    'pointerup',
    'pointerdown',
    'pointermove',
    'pointerenter',
    'pointerleave',
    'pointercancel',
    'pointerout'
];
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/usePointers | usePointers} hook.
 */
const usePointers = (args) => {
    const targetRef = (0, useNewRef_1.useNewRef)(args.ref);
    const pointersList = (0, react_1.useRef)([]);
    const addPointer = (0, react_1.useCallback)((event) => {
        const pointerIndex = pointersList.current.findIndex(e => e.pointerId === event.pointerId);
        if (args.capture)
            targetRef.current?.setPointerCapture(event.pointerId);
        if (pointerIndex === -1)
            pointersList.current.push(event);
        pointersList.current[pointerIndex] = event;
    }, []);
    const removePointer = (0, react_1.useCallback)((event) => {
        pointersList.current = pointersList.current.filter(e => e.pointerId !== event.pointerId);
    }, []);
    const handlePointerEvents = (0, react_1.useCallback)((event) => {
        if (['pointerdown', 'pointermove'].includes(event.type))
            addPointer(event);
        if (['pointerup', 'pointercancel'].includes(event.type))
            removePointer(event);
        args.handler(event, pointersList.current);
    }, [args.handler]);
    (0, useEventListener_1.useEventListener)({ event: pointerEvents, handler: handlePointerEvents, ref: targetRef });
    return targetRef;
};
exports.usePointers = usePointers;
//# sourceMappingURL=index.js.map