"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePreferredLanguage = void 0;
const react_1 = require("react");
const useIsomorphicEffect_1 = require("../useIsomorphicEffect");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/usePreferredLanguage | usePreferredLanguage} hook.
 */
const usePreferredLanguage = () => {
    const [language, setLanguage] = (0, react_1.useState)();
    (0, useIsomorphicEffect_1.useIsomorphicEffect)(() => {
        const updatePreferredLanguage = () => {
            const code = navigator.language;
            const name = new Intl.DisplayNames([code], { type: 'language' }).of(code);
            setLanguage({ code, name });
        };
        updatePreferredLanguage();
        window.addEventListener('languagechange', updatePreferredLanguage);
        return () => window.removeEventListener('languagechange', updatePreferredLanguage);
    }, []);
    return language;
};
exports.usePreferredLanguage = usePreferredLanguage;
//# sourceMappingURL=index.js.map