"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useScreenCapture = void 0;
const react_1 = require("react");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useScreenCapture | useScreenCapture} hook.
 */
const useScreenCapture = (options = {}) => {
    const [stream, setStream] = (0, react_1.useState)(null);
    const [isPending, setIsPending] = (0, react_1.useState)(false);
    const startStreaming = (0, react_1.useCallback)(async () => {
        setIsPending(true);
        stream?.getTracks().forEach(t => t.stop());
        try {
            const newStream = await navigator.mediaDevices.getDisplayMedia(options);
            const videoTrack = newStream.getVideoTracks()[0];
            if (videoTrack)
                videoTrack.onended = () => setStream(null);
            setStream(newStream);
            setIsPending(false);
            return newStream;
        }
        finally {
            setIsPending(false);
        }
    }, [stream]);
    const stopStreaming = (0, react_1.useCallback)(() => {
        stream?.getTracks().forEach(t => t.stop());
        setStream(null);
    }, [stream]);
    return { stream, start: startStreaming, stop: stopStreaming, isPending };
};
exports.useScreenCapture = useScreenCapture;
//# sourceMappingURL=index.js.map