"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useScrollDirection = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useNewRef_1 = require("../utils/useNewRef");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useScrollDirection | useScrollDirection} hook.
 */
const useScrollDirection = (ref) => {
    const targetRef = (0, useNewRef_1.useNewRef)(ref);
    const prevPosition = (0, react_1.useRef)({ x: 0, y: 0 });
    const [direction, setDirection] = (0, react_1.useState)({
        isUp: false,
        isDown: false,
        isLeft: false,
        isRight: false
    });
    const handleScrolling = (0, react_1.useCallback)(() => {
        const x = targetRef.current?.scrollLeft ?? window.scrollX;
        const y = targetRef.current?.scrollTop ?? window.scrollY;
        const distanceX = x - prevPosition.current.x;
        const distanceY = y - prevPosition.current.y;
        prevPosition.current = { x, y };
        setDirection({
            isLeft: distanceX < 0,
            isRight: distanceX > 0,
            isUp: distanceY < 0,
            isDown: distanceY > 0
        });
    }, []);
    (0, useEventListener_1.useEventListener)({
        event: 'scroll',
        handler: handleScrolling,
        target: () => {
            handleScrolling();
            return targetRef.current ?? window;
        }
    });
    return { ref: targetRef, ...direction };
};
exports.useScrollDirection = useScrollDirection;
//# sourceMappingURL=index.js.map