"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useScrollPosition = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useNewRef_1 = require("../utils/useNewRef");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useScrollPosition | useScrollPosition} hook.
 */
const useScrollPosition = (ref) => {
    const targetRef = (0, useNewRef_1.useNewRef)(ref);
    const [position, setPosition] = (0, react_1.useState)({ x: 0, y: 0, progressX: 0, progressY: 0 });
    const handleScrolling = (0, react_1.useCallback)(() => {
        const x = targetRef.current?.scrollLeft ?? window.scrollX;
        const y = targetRef.current?.scrollTop ?? window.scrollY;
        const element = targetRef.current ?? document.body;
        const maxScrollX = element.scrollWidth - element.clientWidth;
        const maxScrollY = element.scrollHeight - element.clientHeight;
        const progressX = maxScrollX ? x / maxScrollX : 1;
        const progressY = maxScrollY ? y / maxScrollY : 1;
        setPosition({ x, y, progressX, progressY });
    }, []);
    (0, useEventListener_1.useEventListener)({
        event: 'scroll',
        handler: handleScrolling,
        target: () => {
            handleScrolling();
            return targetRef.current ?? window;
        }
    });
    return { ref: targetRef, ...position };
};
exports.useScrollPosition = useScrollPosition;
//# sourceMappingURL=index.js.map