"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useScrollThreshold = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useNewRef_1 = require("../utils/useNewRef");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useScrollThreshold | useScrollThreshold} hook.
 */
const useScrollThreshold = (args) => {
    const targetRef = (0, useNewRef_1.useNewRef)(args.ref);
    const [isPast, setIsPast] = (0, react_1.useState)(false);
    const handleScrolling = (0, react_1.useCallback)((event) => {
        if (args.threshold instanceof Function)
            return setIsPast(!!args.threshold(event));
        const x = targetRef.current?.scrollLeft ?? window.scrollX;
        const y = targetRef.current?.scrollTop ?? window.scrollY;
        const target = targetRef.current ?? document.body;
        const { clientWidth, clientHeight, scrollWidth, scrollHeight } = target;
        const { top = 0, bottom = scrollHeight, left = 0, right = scrollWidth } = args.threshold;
        const passedLeft = x >= left;
        const passedRight = x + clientWidth >= scrollWidth - right;
        const passedTop = y >= top;
        const passedBottom = y + clientHeight >= scrollHeight - bottom;
        setIsPast(passedLeft && passedRight && passedTop && passedBottom);
    }, [args.threshold]);
    (0, useEventListener_1.useEventListener)({
        event: 'scroll',
        handler: handleScrolling,
        target: () => {
            handleScrolling();
            return targetRef.current ?? window;
        }
    });
    return { ref: targetRef, isPast };
};
exports.useScrollThreshold = useScrollThreshold;
//# sourceMappingURL=index.js.map