"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSelection = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useNewRef_1 = require("../utils/useNewRef");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useSelection | useSelection} hook.
 */
const useSelection = (ref) => {
    const targetRef = (0, useNewRef_1.useNewRef)(ref);
    const [selection, setSelection] = (0, react_1.useState)({
        text: '',
        rect: undefined,
        isCollapsed: true
    });
    const handleSelectionChange = (0, react_1.useCallback)(() => {
        const currentSelection = document.getSelection();
        const target = currentSelection?.focusNode?.parentElement;
        const text = currentSelection?.toString();
        const isTarget = !!targetRef.current?.contains(target);
        if (!text || (targetRef.current && !isTarget)) {
            return setSelection({ text: '', rect: undefined, isCollapsed: true });
        }
        const selectionRect = currentSelection?.getRangeAt(0).getBoundingClientRect();
        setSelection({
            text,
            rect: selectionRect &&
                new DOMRect(selectionRect.left + window.scrollX, selectionRect.top + window.scrollY, selectionRect.width, selectionRect.height),
            isCollapsed: !!currentSelection?.isCollapsed
        });
    }, [targetRef]);
    (0, useEventListener_1.useEventListener)({
        event: 'selectionchange',
        handler: handleSelectionChange,
        target: () => {
            handleSelectionChange();
            return document;
        },
        passive: true
    });
    return { ...selection, ref: targetRef };
};
exports.useSelection = useSelection;
//# sourceMappingURL=index.js.map