"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSwiping = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const utils_1 = require("../utils");
const useNewRef_1 = require("../utils/useNewRef");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useSwiping | useSwiping} hook.
 */
const useSwiping = (args) => {
    const targetRef = (0, useNewRef_1.useNewRef)(args.ref);
    const delta = (0, react_1.useRef)({ x: 0, y: 0 });
    const initialPosition = (0, react_1.useRef)();
    const callback = (0, react_1.useCallback)((type, event) => {
        if (!initialPosition.current)
            return;
        const currentPosition = (0, utils_1.getPointerPosition)(event);
        delta.current = {
            x: initialPosition.current.x - currentPosition.x,
            y: initialPosition.current.y - currentPosition.y
        };
        args.handler({
            type,
            deltaX: delta.current.x,
            deltaY: delta.current.y,
            initialX: initialPosition.current.x,
            initialY: initialPosition.current.y,
            event
        });
    }, [args.handler]);
    const handleTouchStart = (0, react_1.useCallback)((event) => {
        initialPosition.current = (0, utils_1.getPointerPosition)(event);
        targetRef.current?.setPointerCapture(event.pointerId);
        callback('start', event);
    }, [callback]);
    const handleTouchMove = (0, react_1.useCallback)((event) => callback('moving', event), [callback]);
    const handleTouchEnd = (0, react_1.useCallback)((event) => {
        callback('end', event);
        targetRef.current?.releasePointerCapture(event.pointerId);
        initialPosition.current = undefined;
    }, [callback]);
    (0, useEventListener_1.useEventListener)({ event: 'pointermove', handler: handleTouchMove, ref: targetRef });
    (0, useEventListener_1.useEventListener)({ event: 'pointerdown', handler: handleTouchStart, ref: targetRef });
    (0, useEventListener_1.useEventListener)({
        event: ['pointerup', 'pointercancel'],
        handler: handleTouchEnd,
        ref: targetRef
    });
    return targetRef;
};
exports.useSwiping = useSwiping;
//# sourceMappingURL=index.js.map