"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTimeout = void 0;
const react_1 = require("react");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useTimeout | useTimeout} hook.
 */
const useTimeout = (args) => {
    const timeoutRef = (0, react_1.useRef)();
    const [isActive, setIsActive] = (0, react_1.useState)(!!args.startOnMount);
    const callback = (0, react_1.useCallback)(() => {
        args.callback?.();
        setIsActive(false);
    }, [args.callback]);
    const controls = (0, react_1.useMemo)(() => ({
        isActive,
        start() {
            controls.cancel();
            timeoutRef.current = setTimeout(callback, args.timeout);
            setIsActive(true);
        },
        cancel() {
            if (!timeoutRef.current)
                return;
            setIsActive(false);
            clearTimeout(timeoutRef.current);
        },
        toggle(force) {
            const shouldStart = force ?? !isActive;
            shouldStart ? controls.start() : controls.cancel();
        }
    }), [callback, isActive]);
    (0, react_1.useEffect)(() => {
        if (!args.startOnMount)
            return;
        controls.start();
        return controls.cancel;
    }, args.deps ?? []);
    return controls;
};
exports.useTimeout = useTimeout;
//# sourceMappingURL=index.js.map