"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useWorker = void 0;
const react_1 = require("react");
const useIsomorphicEffect_1 = require("../useIsomorphicEffect");
/**
 * @see {@link https://malkiii.github.io/react-pre-hooks/docs/hooks/useWorker | useWorker} hook.
 */
const useWorker = (args) => {
    const [isLoading, setIsLoading] = (0, react_1.useState)(false);
    const workerRef = (0, react_1.useRef)();
    const controls = (0, react_1.useMemo)(() => ({
        postMessage(message, options) {
            try {
                setIsLoading(true);
                workerRef.current?.postMessage(message, options);
            }
            catch (error) {
                setIsLoading(false);
                throw error;
            }
        },
        terminate() {
            workerRef.current?.terminate();
        }
    }), []);
    (0, useIsomorphicEffect_1.useIsomorphicEffect)(() => {
        const script = typeof args.script === 'string' ? args.script : `(${args.script.toString()})()`;
        const workerScript = URL.createObjectURL(new Blob([script]));
        workerRef.current = new Worker(workerScript);
        workerRef.current.onmessage = event => {
            args.handler({ data: event.data });
            setIsLoading(false);
        };
        workerRef.current.onerror = event => {
            args.handler({ error: event.error });
            setIsLoading(false);
        };
        workerRef.current.onmessageerror = event => {
            args.handler({ error: event.data });
            setIsLoading(false);
        };
        return () => {
            workerRef.current?.terminate();
            URL.revokeObjectURL(workerScript);
        };
    }, []);
    return { ...controls, isLoading };
};
exports.useWorker = useWorker;
//# sourceMappingURL=index.js.map