"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPointerPosition = exports.getStateActionValue = exports.getPrefixedProperty = exports.browserPrefixes = void 0;
exports.browserPrefixes = ['', 'moz', 'webkit', 'o', 'ms'];
function getPrefixedProperty(obj, prop) {
    const property = prop in obj
        ? prop
        : exports.browserPrefixes
            .map(pref => pref + prop.replace(/^\w/, l => l.toUpperCase()))
            .find(p => p in obj);
    if (!property)
        return;
    const resolvedValue = obj[property];
    return resolvedValue instanceof Function ? resolvedValue.bind(obj) : resolvedValue;
}
exports.getPrefixedProperty = getPrefixedProperty;
function getStateActionValue(state, value) {
    return state instanceof Function ? state(value) : state;
}
exports.getStateActionValue = getStateActionValue;
function getPointerPosition(event) {
    const position = event instanceof TouchEvent
        ? { x: event.changedTouches[0].clientX, y: event.changedTouches[0].clientY }
        : { x: event.clientX, y: event.clientY };
    const offset = event.currentTarget instanceof HTMLElement
        ? event.currentTarget.getBoundingClientRect()
        : { left: 0, top: 0 };
    return {
        x: position.x - offset.left,
        y: position.y - offset.top
    };
}
exports.getPointerPosition = getPointerPosition;
//# sourceMappingURL=index.js.map