"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useStorage = void 0;
const react_1 = require("react");
const useEventListener_1 = require("../useEventListener");
const useIsomorphicEffect_1 = require("../useIsomorphicEffect");
const useStorage = (args) => {
    const defaultValue = args.default ?? null;
    const [storedValue, setStoredValue] = (0, react_1.useState)(() => defaultValue);
    const getStorage = (0, react_1.useCallback)(() => (args.type === 'local' ? localStorage : sessionStorage), []);
    const getStoredValue = (0, react_1.useCallback)(() => {
        const item = getStorage().getItem(args.key);
        if (!item)
            return defaultValue;
        return item === 'undefined' ? null : JSON.parse(item ?? '');
    }, [args.key]);
    const updateStoredValue = (0, react_1.useCallback)(value => {
        const newValue = JSON.stringify(value instanceof Function ? value(storedValue) : value);
        getStorage().setItem(args.key, newValue);
        window.dispatchEvent(new StorageEvent('storage', { key: args.key, newValue }));
    }, []);
    const handleStorageChange = (0, react_1.useCallback)((event) => {
        if (event?.key === args.key)
            setStoredValue(getStoredValue());
    }, [args.key]);
    (0, useIsomorphicEffect_1.useIsomorphicEffect)(() => {
        setStoredValue(getStoredValue());
    }, []);
    (0, useEventListener_1.useEventListener)({
        event: 'storage',
        handler: handleStorageChange,
        target: () => window
    });
    return [storedValue, updateStoredValue];
};
exports.useStorage = useStorage;
//# sourceMappingURL=useStorage.js.map